@@ -121,6 +121,11 @@ func Release() *cli.Command {
 				Value:       "",
 				Destination: &r.icon,
 			},
+			&cli.GenericFlag{
+				Name:  "metadata",
+				Usage: "Specify custom metadata key value pair that you do not want to store in your FyneApp.toml (key=value)",
+				Value: &r.customMetadata,
+			},
 		},
 		Action: r.releaseAction,
 	}
@@ -346,9 +351,9 @@ func (r *Releaser) packageWindowsRelease(outFile string) error {
 	manifestData := struct{ AppID, Developer, DeveloperName, Name, Version string }{
 		AppID: r.AppID,
 		// TODO read this info
-		Developer:     r.developer,
-		DeveloperName: r.nameFromCertInfo(r.developer),
-		Name:          r.Name,
+		Developer:     encodeXMLString(r.developer),
+		DeveloperName: encodeXMLString(r.nameFromCertInfo(r.developer)),
+		Name:          encodeXMLString(r.Name),
 		Version:       r.combinedVersion(),
 	}
 	err = templates.AppxManifestWindows.Execute(manifest, manifestData)
